Function linux_stat::raw::fstatat

source ·
pub unsafe fn fstatat<P: AsRef<Path>>(
    dirfd: RawFd,
    path: P,
    flags: StatAtFlags
) -> Result<stat, Errno>
Invoke fstatat system call.

Safety

This functions is inherently unsafe because it just wrap the system call and directory file descriptor (dirfd) cannot be checked.