Function linux_stat::raw::fstatat_cstr

source ·
pub unsafe fn fstatat_cstr(
    dirfd: RawFd,
    path: &CStr,
    flags: StatAtFlags
) -> Result<stat, Errno>
Invoke fstatat system call with path as a crate::CStr.

Safety

This functions is inherently unsafe because it just wrap the system call and directory file descriptor (dirfd) cannot be checked.